<?php

namespace Litecms\Travelling\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Travelling\Models\Travelling;

class TravellingPolicy
{

    /**
     * Determine if the given user can view the travelling.
     *
     * @param UserPolicy $user
     * @param Travelling $travelling
     *
     * @return bool
     */
    public function view(UserPolicy $user, Travelling $travelling)
    {
        if ($user->canDo('travelling.travelling.view') && $user->isAdmin()) {
            return true;
        }

        return $travelling->user_id == user_id() && $travelling->user_type == user_type();
    }

    /**
     * Determine if the given user can create a travelling.
     *
     * @param UserPolicy $user
     * @param Travelling $travelling
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('travelling.travelling.create');
    }

    /**
     * Determine if the given user can update the given travelling.
     *
     * @param UserPolicy $user
     * @param Travelling $travelling
     *
     * @return bool
     */
    public function update(UserPolicy $user, Travelling $travelling)
    {
        if ($user->canDo('travelling.travelling.edit') && $user->isAdmin()) {
            return true;
        }

        return $travelling->user_id == user_id() && $travelling->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given travelling.
     *
     * @param UserPolicy $user
     * @param Travelling $travelling
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Travelling $travelling)
    {
        return $travelling->user_id == user_id() && $travelling->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given travelling.
     *
     * @param UserPolicy $user
     * @param Travelling $travelling
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Travelling $travelling)
    {
        if ($user->canDo('travelling.travelling.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given travelling.
     *
     * @param UserPolicy $user
     * @param Travelling $travelling
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Travelling $travelling)
    {
        if ($user->canDo('travelling.travelling.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
